@@ -23,11 +23,11 @@
 #' DataApes$Tstage->Tstage
 #'
 #' cc<- 2/parallel::detectCores()
-#' distNodes(tree=Tstage,clus=cc)
-#' distNodes(tree=Tstage,node=64,clus=cc)
-#' distNodes(tree=Tstage,node="Tro_2",clus=cc)
-#' distNodes(tree=Tstage,node=c(64,48),clus=cc)
-#' distNodes(tree=Tstage,node=c(64,"Tro_2"),clus=cc)
+#' distNodes(tree=Tstage,clus=cc)->dn1
+#' distNodes(tree=Tstage,node=64,clus=cc)->dn2
+#' distNodes(tree=Tstage,node="Tro_2",clus=cc)->dn3
+#' distNodes(tree=Tstage,node=c(64,48),clus=cc)->dn4
+#' distNodes(tree=Tstage,node=c(64,"Tro_2"),clus=cc)->dn5
 #' }
 
 distNodes<-function(tree,node=NULL,clus=0.5){
@@ -51,72 +51,78 @@ distNodes<-function(tree,node=NULL,clus=0.5){
   as.numeric(nam)->nam
   if(is.null(node)){
     matrix(ncol=ncol(L),nrow=ncol(L))->mat
-    i=1
-    res<-list()
-    if(round((detectCores() * clus), 0)==0) cl<-makeCluster(1, setup_strategy = "sequential") else cl <- makeCluster(round((detectCores() * clus), 0), setup_strategy = "sequential")
-    registerDoParallel(cl)
-    res <- foreach(i = 1:length(nam),
-                   .packages = c("RRphylo","ape", "phytools", "doParallel")) %dopar%
-      {
-        gc()
-        nam[i]->n1
-        mata<-array()
-        for(j in i:length(nam)){
-          nam[j]->n2
-          if(n1==n2) ll<-0 else{
-            if(n1>Ntip(tree)&n2>Ntip(tree)){
-              if(n2%in%c(getMommy(tree,n1),getDescendants(tree,n1))){
-                c(n1,n2)->nn
-                nn[which.min(nn)]->mrca
-                nn[which.max(nn)]->n
-                getDescendants(tree,mrca)->des
-                des[which(des>Ntip(tree))]->ndes
-                length(which(names(which(L1[which(rownames(L1)==n),]>0))%in%ndes))->ll
-              }else{
-                getMRCA(tree,c(n1,n2))->mrca
-                getDescendants(tree,mrca)->des
-                des[which(des>Ntip(tree))]->ndes
-                length(which(names(which(L1[which(rownames(L1)==n1),]>0))%in%ndes))->l1
-                length(which(names(which(L1[which(rownames(L1)==n2),]>0))%in%ndes))->l2
-                l1+l2->ll
-              }
-            }
 
-
-            if(n1<=Ntip(tree)&n2<=Ntip(tree)){
-              getMRCA(tree,c(tree$tip.label[n1],tree$tip.label[n2]))->mrca
+    core.chunk<-  expression({
+      nam[i]->n1
+      mata<-array()
+      for(j in i:length(nam)){
+        nam[j]->n2
+        if(n1==n2) ll<-0 else{
+          if(n1>Ntip(tree)&n2>Ntip(tree)){
+            if(n2%in%c(getMommy(tree,n1),getDescendants(tree,n1))){
+              c(n1,n2)->nn
+              nn[which.min(nn)]->mrca
+              nn[which.max(nn)]->n
               getDescendants(tree,mrca)->des
-              des[which(des<=Ntip(tree))]<-tree$tip.label[des[which(des<=Ntip(tree))]]
-              length(which(names(which(L[which(rownames(L)==tree$tip.label[n1]),]>0))%in%des))->l1
-              length(which(names(which(L[which(rownames(L)==tree$tip.label[n2]),]>0))%in%des))->l2
-              l1+l2-1->ll
-            }
-
-            if(n1>Ntip(tree)&n2<=Ntip(tree)|n1<=Ntip(tree)&n2>Ntip(tree)){
-              if(n2%in%c(getMommy(tree,n1),getDescendants(tree,n1))){
-                c(n1,n2)->nn
-                nn[which.max(nn)]->mrca
-                nn[which.min(nn)]->n
-                getDescendants(tree,mrca)->des
-                des[which(des<=Ntip(tree))]<-tree$tip.label[des[which(des<=Ntip(tree))]]
-                length(which(names(which(L[which(rownames(L)==tree$tip.label[n]),]>0))%in%des))->ll
-              }else{
-                getMRCA(tree,c(n1,n2))->mrca
-                getDescendants(tree,mrca)->des
-                des[which(des<=Ntip(tree))]<-tree$tip.label[des[which(des<=Ntip(tree))]]
-                length(which(names(which(L[which(rownames(L)==tree$tip.label[c(n1,n2)[which.min(c(n1,n2))]]),]>0))%in%des))->l1
-                length(which(names(which(L1[which(rownames(L1)==c(n1,n2)[which.max(c(n1,n2))]),]>0))%in%des))->l2
-                l1+l2->ll
-              }
+              des[which(des>Ntip(tree))]->ndes
+              length(which(names(which(L1[which(rownames(L1)==n),]>0))%in%ndes))->ll
+            }else{
+              getMRCA(tree,c(n1,n2))->mrca
+              getDescendants(tree,mrca)->des
+              des[which(des>Ntip(tree))]->ndes
+              length(which(names(which(L1[which(rownames(L1)==n1),]>0))%in%ndes))->l1
+              length(which(names(which(L1[which(rownames(L1)==n2),]>0))%in%ndes))->l2
+              l1+l2->ll
             }
           }
 
-          ll->mata[j]
-        }
-        mata->res[[i]]
-      }
-    stopCluster(cl)
 
+          if(n1<=Ntip(tree)&n2<=Ntip(tree)){
+            getMRCA(tree,c(tree$tip.label[n1],tree$tip.label[n2]))->mrca
+            getDescendants(tree,mrca)->des
+            des[which(des<=Ntip(tree))]<-tree$tip.label[des[which(des<=Ntip(tree))]]
+            length(which(names(which(L[which(rownames(L)==tree$tip.label[n1]),]>0))%in%des))->l1
+            length(which(names(which(L[which(rownames(L)==tree$tip.label[n2]),]>0))%in%des))->l2
+            l1+l2-1->ll
+          }
+
+          if(n1>Ntip(tree)&n2<=Ntip(tree)|n1<=Ntip(tree)&n2>Ntip(tree)){
+            if(n2%in%c(getMommy(tree,n1),getDescendants(tree,n1))){
+              c(n1,n2)->nn
+              nn[which.max(nn)]->mrca
+              nn[which.min(nn)]->n
+              getDescendants(tree,mrca)->des
+              des[which(des<=Ntip(tree))]<-tree$tip.label[des[which(des<=Ntip(tree))]]
+              length(which(names(which(L[which(rownames(L)==tree$tip.label[n]),]>0))%in%des))->ll
+            }else{
+              getMRCA(tree,c(n1,n2))->mrca
+              getDescendants(tree,mrca)->des
+              des[which(des<=Ntip(tree))]<-tree$tip.label[des[which(des<=Ntip(tree))]]
+              length(which(names(which(L[which(rownames(L)==tree$tip.label[c(n1,n2)[which.min(c(n1,n2))]]),]>0))%in%des))->l1
+              length(which(names(which(L1[which(rownames(L1)==c(n1,n2)[which.max(c(n1,n2))]),]>0))%in%des))->l2
+              l1+l2->ll
+            }
+          }
+        }
+
+        ll->mata[j]
+      }
+      mata
+    })
+
+    cldef<-({
+      'cl <- makeCluster(round((detectCores() * clus), 0), setup_strategy = "sequential")
+     clusterEvalQ(cl, {library(ape)\nlibrary(phytools)})
+    '
+    })
+
+
+    i=NULL
+    res=NULL
+    if(round((detectCores() * clus), 0)>1)
+      eval(parse(text=paste0(cldef,'\nres<-parLapply(cl=cl,1:length(nam),function(i)',
+                             core.chunk,")\n stopCluster(cl)"))) else
+                               eval(parse(text=paste0('res<-lapply(1:length(nam),function(i)',core.chunk,")")))
     do.call(rbind,res)->mat
     t(mat)[lower.tri(t(mat))]->mat[lower.tri(mat)]
     colnames(mat)<-rownames(mat)<-colnames(L)
